@@ -1,12 +1,14 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-#ifndef GNM_PRINT_INFO_H
-#define GNM_PRINT_INFO_H
+#ifndef _GNM_PRINT_INFO_H_
+# define _GNM_PRINT_INFO_H_
 
 #include "gnumeric.h"
-#include <gtk/gtk.h>
+#include <gtk/gtkpagesetup.h>
+
+G_BEGIN_DECLS
 
 typedef struct {
-  GtkUnit   top, bottom, left, right, header, footer;
+	GtkUnit   top, bottom, left, right, header, footer;
 } DesiredDisplay;
 
 /* Header/Footer definition */
@@ -60,7 +62,7 @@ struct _PrintInformation {
 		} dim;
 	} scaling;
 	double           edge_to_below_header;
-	double           edge_to_above_footer; 
+	double           edge_to_above_footer;
         DesiredDisplay   desired_display;
 	PrintRepeatRange repeat_top, repeat_left;
 	unsigned int	 print_across_then_down;
@@ -73,6 +75,7 @@ struct _PrintInformation {
 
 	/* Gnumeric specific */
 	unsigned int     print_even_if_only_styles:1;
+	unsigned int     do_not_print:1;
 
 	enum {
 		PRINT_COMMENTS_NONE,
@@ -107,6 +110,8 @@ typedef struct {
 	int       page;
 	int       pages;
 	GnmValue *date_time;
+	GnmRange  page_area;
+	GnmCellPos top_repeating;
 } HFRenderInfo;
 
 PrintInformation *print_info_new         (gboolean load_defaults);
@@ -139,8 +144,8 @@ char const *unit_to_unit_name (GtkUnit unit);
 void        print_init               (void);
 void        print_shutdown           (void);
 
-void	    page_setup_set_paper	(GtkPageSetup *page_setup, char const *paper);
-void	    print_info_set_paper     	   (PrintInformation *pi, char const *paper);
+gboolean    page_setup_set_paper	(GtkPageSetup *page_setup, char const *paper);
+gboolean    print_info_set_paper     	   (PrintInformation *pi, char const *paper);
 void	    print_info_set_paper_orientation   (PrintInformation *pi,
 						GtkPageOrientation orientation);
 char 	   *page_setup_get_paper (GtkPageSetup *page_setup);
@@ -180,4 +185,6 @@ gboolean	 gnm_page_breaks_append_break	(GnmPageBreaks *breaks,
 /* Formats known */
 extern GList *hf_formats;
 
-#endif /* GNM_PRINT_INFO_H */
+G_END_DECLS
+
+#endif /* _GNM_PRINT_INFO_H_ */
