@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-#ifndef GNM_SHEET_H
-#define GNM_SHEET_H
+#ifndef _GNM_SHEET_H_
+# define _GNM_SHEET_H_
 
 #include "gnumeric.h"
 #include "colrow.h"
@@ -8,6 +8,8 @@
 #include <pango/pango.h>
 #include <goffice/utils/go-undo.h>
 
+G_BEGIN_DECLS
+
 typedef struct _SheetPrivate SheetPrivate;
 typedef enum {
 	GNM_SHEET_DATA,
@@ -95,7 +97,6 @@ struct _Sheet {
 	GnmDepContainer *deps;
 
 	GSList		 *filters;
-	GSList		 *pivottables;
 	GSList		 *list_merged;
 	GHashTable	 *hash_merged;
 	SheetPrivate     *priv;
@@ -300,26 +301,16 @@ gboolean     sheet_selection_is_allowed (Sheet const *sheet, GnmCellPos const *p
 
 GnmConventions const *sheet_get_conventions (Sheet const *sheet);
 
-/* Implementation for commands, no undo */
-struct _GnmRelocUndo {
-	GSList *exprs;
-	GSList *objs;
-};
-
-gboolean  sheet_insert_cols (Sheet *sheet,
-			     int col, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
-gboolean  sheet_delete_cols (Sheet *sheet,
-			     int col, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
-gboolean  sheet_insert_rows (Sheet *sheet,
-			     int row, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
-gboolean  sheet_delete_rows (Sheet *sheet,
-			     int row, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
+gboolean  sheet_insert_cols (Sheet *sheet, int col, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
+gboolean  sheet_delete_cols (Sheet *sheet, int col, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
+gboolean  sheet_insert_rows (Sheet *sheet, int row, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
+gboolean  sheet_delete_rows (Sheet *sheet, int row, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
 void      sheet_move_range   (GnmExprRelocateInfo const *rinfo,
-			      GnmRelocUndo *reloc_storage, GOCmdContext *cc);
+			      GOUndo **pundo, GOCmdContext *cc);
 
 
 typedef enum {
@@ -368,4 +359,6 @@ do {										\
 	}										\
   } while (0)
 
-#endif /* GNM_SHEET_H */
+G_END_DECLS
+
+#endif /* _GNM_SHEET_H_ */
